#
# spec file for package gnome-video-arcade
#
# Copyright (c) 2012 Guido Berhoerster <gber@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           gnome-video-arcade
Version:        0.8.3
Release:        2.4
Summary:        MAME Frontend for the GNOME Desktop
License:        GPL-3.0+
Group:          System/Emulators/Other
Url:            https://live.gnome.org/GnomeVideoArcade
Source:         http://download.gnome.org/sources/gnome-video-arcade/0.8/%{name}-%{version}.tar.xz
# PATCH-FEATURE-OPENSUSE gnome-video-arcade-fix-build-on-11.4.patch gber@opensuse.org -- Disable features in order to allow building on openSUSE 11.4
Patch0:         gnome-video-arcade-fix-build-on-11.4.patch
BuildRequires:  gnome-doc-utils-devel
BuildRequires:  intltool
BuildRequires:  update-desktop-files
BuildRequires:  xz
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gnome-icon-theme)
BuildRequires:  pkgconfig(gsettings-desktop-schemas)
BuildRequires:  pkgconfig(gstreamer-0.10)
BuildRequires:  pkgconfig(gstreamer-plugins-base-0.10)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(libsoup-2.4)
%if 0%{?suse_version} >= 1210
BuildRequires:  pkgconfig(libwnck-3.0)
%endif
BuildRequires:  pkgconfig(sqlite3)
BuildRequires:  pkgconfig(x11)
%glib2_gsettings_schema_requires
Recommends:     %{name}-lang = %{version}
Requires:       mame
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
GNOME Video Arcade is a simple MAME frontend for the GNOME desktop. Its chief
design goal is to help you quickly find a game to play and then get out of the
way.  Its purpose is not to help you manage your ROM collection, nor to provide
a confusing graphical interface for MAME's plethora of configuration options.
It can utilize third-party data files like arcade history and game categories.

%lang_package

%prep
%setup -q
%if 0%{?suse_version} < 1210
%patch0 -p1
%endif

%build
export MAME=/usr/bin/mame
%configure \
    --with-category-file=%{_datadir}/mame/Catver.ini \
    --with-history-file=%{_datadir}/mame/history.dat \
    --with-nplayers-file=%{_datadir}/mame/nplayers.ini \
%if 0%{?suse_version} < 1210
    --with-wnck=no \
%endif
    --disable-schemas-install \
    --disable-scrollkeeper
make %{?_smp_mflags} V=1

%install
%make_install
rm -rf %{buildroot}%{_mandir}/man1/
rm -rf %{buildroot}%{_datadir}/gtk-doc/

install -d -m 755 %{buildroot}%{_mandir}/man6/
sed -e 's/^.TH GNOME-VIDEO-ARCADE "1"/.TH GNOME-VIDEO-ARCADE "6"/' \
    docs/gnome-video-arcade.1 > %{buildroot}%{_mandir}/man6/gnome-video-arcade.6

%suse_update_desktop_file -r %{name} 'System;Emulator;'

%find_lang %{name} %{?no_lang_C}

%post
%glib2_gsettings_schema_post
%desktop_database_post
%icon_theme_cache_post

%postun
%glib2_gsettings_schema_postun
%desktop_database_postun
%icon_theme_cache_postun

%files
%defattr(-, root, root, -)
%doc AUTHORS ChangeLog COPYING NEWS README
%doc %{_mandir}/man6/gnome-video-arcade.6*
%dir %{_datadir}/gnome/
%dir %{_datadir}/gnome/help/
%dir %{_datadir}/gnome/help/%{name}/
%doc %{_datadir}/gnome/help/%{name}/C/
%dir %{_datadir}/omf/
%dir %{_datadir}/omf/%{name}/
%doc %{_datadir}/omf/%{name}/%{name}-C.omf
%{_bindir}/gnome-video-arcade
%{_datadir}/GConf/gsettings/gnome-video-arcade.convert
%{_datadir}/glib-2.0/schemas/org.gnome.VideoArcade.gschema.xml
%{_datadir}/gnome-video-arcade/
%{_datadir}/applications/gnome-video-arcade.desktop
%{_datadir}/icons/hicolor/scalable/apps/gnome-video-arcade.svg

%files lang -f %{name}.lang

%changelog
* Mon May  7 2012 gber@opensuse.org
- specfile cleanup
- allow building on openSUSE 11.4 again by disabling any features
  not available, added gnome-video-arcade-fix-build-on-11.4.patch
* Fri May  4 2012 gber@opensuse.org
- update to version 0.8.3
  - adapt to MAME 0.144 -listxml DTD
  - fixed some unsightly spacing glitches in the UI caused by
    widget packing changes in GTK v3 versus v2
  - further bugfixes
  - translation updates
- dropped obsolete gnome-video-arcade-0.8.0-add-missing-libs.patch
* Sun Dec 25 2011 gber@opensuse.org
- update to version 0.8.0
  - the feature set of version 0.8.0 is identical to 0.7.1, but now
    uses current GNOME 3 technologies and drops several GNOME 2 era
    dependencies such as GConf, libunique, and dbus-glib.
  - translation updates
- added gnome-video-arcade-0.8.0-add-missing-libs.patch in order to
  link explicitly against libX11
* Wed Dec  7 2011 gber@opensuse.org
- call %%desktop_database_post/un and %%icon_theme_cache_post/un
* Tue Dec  6 2011 gber@opensuse.org
- fixed dependencies for >= 12.1
* Mon Jul 19 2010 guido+packman@berhoerster.name
- update to version 0.7.1
  * now detects changes in the ROM directory while running
  * allow only one instance to run
* Fri May  7 2010 guido+packman@berhoerster.name
- updated to release 0.7.0
  * music clips of the selected game can now be played from the Properties window
  * search entry has a "clear search" button
  * position of main window is remembered across sessions
  * size of Properties window is remembered across sessions
  * about dialog has a link to the GNOME Video Arcade website
  * better error handling when data files like Catver.ini and
    nplayers.ini are missing or unparsable
  * strange resizing behavior in the Properties window was fixed
* Mon Mar 15 2010 guido+packman@berhoerster.name
- use _smp_mflags macro
* Mon Mar  8 2010 guido+packman@berhoerster.name
- initial packaging of gnome-video-arcade
